package com.anren.deeplink;

import android.net.Uri;

import com.facebook.react.ReactActivity;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.WritableArray;
import com.facebook.react.bridge.WritableMap;
import com.facebook.react.bridge.WritableNativeArray;
import com.facebook.react.bridge.WritableNativeMap;
import com.facebook.react.modules.core.DeviceEventManagerModule;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;

import javax.annotation.Nullable;

/**
 * Created by lcg on 2018/4/11.
 */

public class DeepLinkModule extends ReactContextBaseJavaModule {
    private static final String EVENT_HANDLE_URL = "EVENT_HANDLE_URL";

    private boolean mBeListenedByJs = false;

    public DeepLinkModule(ReactApplicationContext reactContext) {
        super(reactContext);

        DeepLink.getInstance().setApplicationContext(reactContext);
    }

    @Override
    public String getName() {
        return "RNDeepLink";
    }

    @Nullable
    @Override
    public Map<String, Object> getConstants() {
        final Map<String, Object> constants = new HashMap<>();

        constants.put(EVENT_HANDLE_URL,EVENT_HANDLE_URL);

        return constants;
    }

    public void handleUrl(Uri uri) {
        if (mBeListenedByJs) {
            sendUrl();
        }
    }

    void sendUrl() {
        if (DeepLink.getInstance().getDeepLinks().size() == 0) {
            return ;
        }

        WritableArray deeplinks = new WritableNativeArray();

        for (Uri uri : DeepLink.getInstance().getDeepLinks()) {
            String url = uri.toString();
            String scheme = uri.getScheme();
            String host = uri.getHost();
            int port = uri.getPort();
            String path = uri.getPath();
            String query = uri.getQuery();
            String fregment = uri.getFragment();

            WritableMap deeplink = new WritableNativeMap();
            if (url == null || url.length() == 0) {
                deeplink.putNull("url");
            } else {
                deeplink.putString("url", url);
            }

            if (scheme == null || scheme.length() == 0) {
                deeplink.putNull("scheme");
            } else {
                deeplink.putString("scheme", scheme);
            }

            if (host == null || host.length() == 0) {
                deeplink.putNull("host");
            } else {
                deeplink.putString("host", host);
            }

            if (port == -1) {
                deeplink.putNull("port");
            } else {
                deeplink.putInt("port", port);
            }

            if (path == null || path.length() == 0) {
                deeplink.putNull("path");
            } else {
                deeplink.putString("path", path);
            }

            if ( query == null || query.length() == 0) {
                deeplink.putNull("query");
            } else {
                deeplink.putString("query", query);
            }

            if (fregment == null || fregment.length() == 0) {
                deeplink.putNull("fregment");
            } else {
                deeplink.putString("fregment", fregment);
            }

            deeplinks.pushMap(deeplink);
        }

        getReactApplicationContext().getJSModule(DeviceEventManagerModule.RCTDeviceEventEmitter.class)
                .emit(EVENT_HANDLE_URL, deeplinks);

        DeepLink.getInstance().clearDeepLinks();
    }

    @ReactMethod
    void startObserving() {
        mBeListenedByJs = true;

        sendUrl();
    }

    @ReactMethod
    void stopObserving() {
        mBeListenedByJs = false;
    }
}
