//
//  RNDeepLink.m
//  RNDeepLink
//
//  Created by lcg on 2018/4/10.
//  Copyright © 2018年 anren. All rights reserved.
//

#import "RNDeepLink.h"
#import <Foundation/Foundation.h>
#import "React/RCTRootView.h"

#define EVENT_HANDLE_URL @"EVENT_HANDLE_URL"

@interface RNDeepLink()

@property (nonatomic, strong) NSMutableArray* deepLinks;
@property (nonatomic, assign) BOOL beListenedByJs;

@end

@implementation RNDeepLink

RCT_EXPORT_MODULE(RNDeepLink);

- (NSArray<NSString *> *)supportedEvents
{
    return @[EVENT_HANDLE_URL];
}

- (NSDictionary *)constantsToExport
{
    return @{EVENT_HANDLE_URL: EVENT_HANDLE_URL};
}

- (instancetype)init
{
    self = [super init];
    if (self) {
        _deepLinks = [[NSMutableArray alloc] init];
    
    }
    return self;
}

- (void)handleURL:(NSURL*)url
{
    [self.deepLinks addObject:url];
    
    if (self.beListenedByJs)
    {
        [self sendUrl];
    }
}

- (void)sendUrl
{
    if (self.deepLinks.count == 0)
    {
        return ;
    }
    
    NSMutableArray *urlInfos = [[NSMutableArray alloc] init];
    
    for (NSURL* deepLink in self.deepLinks)
    {
        NSString *url = deepLink.absoluteString;
        NSString *scheme = deepLink.scheme;
        NSString *host = deepLink.host;
        NSNumber *port = deepLink.port;
        NSString *path = deepLink.path;
        NSString *query = deepLink.query;
        NSString *fragment = deepLink.fragment;
        
        NSDictionary *urlInfo = @{
                              @"url": url ? url : [NSNull null],
                              @"scheme": scheme ? scheme : [NSNull null],
                              @"host": host ? host : [NSNull null],
                              @"port": port ? port : [NSNull null],
                              @"path": path ? path : [NSNull null],
                              @"query": query ? query : [NSNull null],
                              @"fragment": fragment ? fragment : [NSNull null]
                             };
        
        [urlInfos addObject:urlInfo];
    }
    
    [self sendEventWithName:EVENT_HANDLE_URL body:urlInfos];
    [self.deepLinks removeAllObjects];
}

+ (BOOL)handleURL:(NSURL *)url
{
    UIWindow* window = [UIApplication sharedApplication].keyWindow;
    RCTRootView* rootView = (RCTRootView*)window.rootViewController.view;
    RNDeepLink* deepLinkModule = (RNDeepLink*)[rootView.bridge moduleForClass: [RNDeepLink class]];
    
    if (!deepLinkModule) {
        return NO;
    }
    
    [deepLinkModule handleURL:url];
    
    return YES;
}

+ (BOOL)handleUserActivity:(NSUserActivity *)userActivity
{
    if(![userActivity.activityType isEqualToString:NSUserActivityTypeBrowsingWeb])
    {
        return NO;
    }
    
    return [self handleURL:userActivity.webpageURL];
}

#pragma mark - RCTEventEmitter

- (void)startObserving
{
    self.beListenedByJs = YES;
    
    [self sendUrl];
}

- (void)stopObserving
{
    self.beListenedByJs = NO;
}

@end
